@@ -1,4 +1,5 @@
 import itertools
+import pickle
 from textwrap import dedent
 from urllib.request import urlopen
 
@@ -23,11 +24,12 @@ from ..datasets import (
     forecast,
     mollwds,
     multiple,
+    pomds,
     popds,
     romsds,
     vert,
 )
-from . import raise_if_dask_computes, requires_pint
+from . import raise_if_dask_computes, requires_cftime, requires_pint
 
 mpl.use("Agg")
 
@@ -298,6 +300,11 @@ def test_getitem_ancillary_variables():
     with pytest.warns(UserWarning):
         anc[["q"]].cf["q"]
 
+    with pytest.warns(None) as record:
+        with cf_xarray.set_options(warn_on_missing_variables=False):
+            anc[["q"]].cf["q"]
+            assert len(record) == 0
+
     for k in ["ULONG", "ULAT"]:
         assert k not in popds.cf["TEMP"].coords
 
@@ -509,7 +516,7 @@ def test_dataarray_getitem():
 
 def test_dataarray_plot():
 
-    obj = airds.air
+    obj = airds.air.copy(deep=True)
 
     rv = obj.isel(time=1).transpose("lon", "lat").cf.plot()
     assert isinstance(rv, mpl.collections.QuadMesh)
@@ -554,15 +561,18 @@ def test_dataarray_plot():
     np.testing.assert_equal(rv[0].get_xdata(), obj.lon.data)
     plt.close()
 
+    obj.lon.attrs["positive"] = "down"
     rv = obj.cf.isel(T=1, Y=[0, 1, 2]).cf.plot(hue="Y")
     np.testing.assert_equal(rv[0].get_xdata(), obj.lon.data)
+    xlim = rv[0].axes.get_xlim()
+    assert xlim[0] > xlim[1]
     plt.close()
+    del obj.lon.attrs["positive"]
 
     rv = obj.cf.isel(T=1, Y=[0, 1, 2]).cf.plot.line()
     np.testing.assert_equal(rv[0].get_xdata(), obj.lon.data)
     plt.close()
 
-    obj = obj.copy(deep=True)
     obj.time.attrs.clear()
     rv = obj.cf.plot(x="X", y="Y", col="time")
     assert isinstance(rv, xr.plot.FacetGrid)
@@ -605,21 +615,23 @@ def test_getitem_errors(obj):
         obj2.cf["X"]
 
 
-def test_getitem_ignores_bad_measure_attribute():
+def test_bad_cell_measures_attribute():
     air2 = airds.copy(deep=True)
-    air2.air.attrs["cell_measures"] = "asd"
+    air2.air.attrs["cell_measures"] = "--OPT"
     with pytest.warns(UserWarning):
         assert_identical(air2.air.drop_vars("cell_area"), air2.cf["air"])
-
-    with pytest.raises(ValueError):
-        air2.cf.cell_measures
-    with pytest.raises(ValueError):
-        air2.air.cf.cell_measures
+    with pytest.warns(UserWarning):
+        assert air2.cf.cell_measures == {}
+    with pytest.warns(UserWarning):
+        assert air2.air.cf.cell_measures == {}
     with pytest.raises(ValueError):
         air2.cf.get_associated_variable_names("air", error=True)
     with pytest.warns(UserWarning):
         air2.cf.get_associated_variable_names("air", error=False)
 
+    #  GH216
+    repr(air2.cf)
+
 
 def test_getitem_clash_standard_name():
     ds = xr.Dataset()
@@ -687,9 +699,10 @@ def test_plot_xincrease_yincrease():
         assert lim[0] > lim[1]
 
 
-@pytest.mark.parametrize("dims", ["lat", "time", ["lat", "lon"]])
-@pytest.mark.parametrize("obj", [airds])
-def test_add_bounds(obj, dims):
+@pytest.mark.parametrize("dims", ["time2", "lat", "time", ["lat", "lon"]])
+def test_add_bounds(dims):
+    obj = airds.copy(deep=True)
+
     expected = {}
     expected["lat"] = xr.concat(
         [
@@ -716,10 +729,12 @@ def test_add_bounds(obj, dims):
         ],
         dim="bounds",
     )
+    expected["time2"] = expected["time"]
     expected["lat"].attrs.clear()
     expected["lon"].attrs.clear()
     expected["time"].attrs.clear()
 
+    obj.coords["time2"] = obj.time
     added = obj.cf.add_bounds(dims)
     if isinstance(dims, str):
         dims = (dims,)
@@ -730,6 +745,8 @@ def test_add_bounds(obj, dims):
         assert added[dim].attrs["bounds"] == name
         assert_allclose(added[name].reset_coords(drop=True), expected[dim])
 
+
+def test_add_bounds_multiple():
     # Test multiple dimensions
     assert not {"x1_bounds", "x2_bounds"} <= set(multiple.variables)
     assert {"x1_bounds", "x2_bounds"} <= set(multiple.cf.add_bounds("X").variables)
@@ -1018,32 +1035,47 @@ def test_param_vcoord_ocean_s_coord():
         romsds.hc + romsds.h
     )
     expected = romsds.zeta + (romsds.zeta + romsds.h) * Zo_rho
-    romsds.cf.decode_vertical_coords()
+    romsds.cf.decode_vertical_coords(outnames={"s_rho": "z_rho"})
     assert_allclose(
         romsds.z_rho.reset_coords(drop=True), expected.reset_coords(drop=True)
     )
 
     romsds.s_rho.attrs["standard_name"] = "ocean_s_coordinate_g1"
     Zo_rho = romsds.hc * (romsds.s_rho - romsds.Cs_r) + romsds.Cs_r * romsds.h
+
     expected = Zo_rho + romsds.zeta * (1 + Zo_rho / romsds.h)
-    romsds.cf.decode_vertical_coords()
+    romsds.cf.decode_vertical_coords(outnames={"s_rho": "z_rho"})
     assert_allclose(
         romsds.z_rho.reset_coords(drop=True), expected.reset_coords(drop=True)
     )
 
-    romsds.cf.decode_vertical_coords(prefix="ZZZ")
+    romsds.cf.decode_vertical_coords(outnames={"s_rho": "ZZZ_rho"})
     assert "ZZZ_rho" in romsds.coords
 
     copy = romsds.copy(deep=True)
     del copy["zeta"]
     with pytest.raises(KeyError):
-        copy.cf.decode_vertical_coords()
+        copy.cf.decode_vertical_coords(outnames={"s_rho": "z_rho"})
 
     copy = romsds.copy(deep=True)
     copy.s_rho.attrs["formula_terms"] = "s: s_rho C: Cs_r depth: h depth_c: hc"
     with pytest.raises(KeyError):
+        copy.cf.decode_vertical_coords(outnames={"s_rho": "z_rho"})
+
+
+def test_param_vcoord_ocean_sigma_coordinate():
+    expected = pomds.zeta + pomds.sigma * (pomds.depth + pomds.zeta)
+    pomds.cf.decode_vertical_coords(outnames={"sigma": "z"})
+    assert_allclose(pomds.z.reset_coords(drop=True), expected.reset_coords(drop=True))
+
+    copy = pomds.copy(deep=True)
+    del copy["zeta"]
+    with pytest.raises(AssertionError):
         copy.cf.decode_vertical_coords()
 
+    with pytest.raises(KeyError):
+        copy.cf.decode_vertical_coords(outnames={})
+
 
 def test_formula_terms():
     srhoterms = {
@@ -1218,6 +1250,14 @@ def test_possible_x_y_plot():
     assert _possible_x_y_plot(xtds, "y") is None
     assert _possible_x_y_plot(xtds, "x") == "X"
 
+    xtds.coords["lon"] = ("X", [1, 2, 3], {"standard_name": "longitude"})
+    # skip lon (which is 1D on X) if user passes hue="X"
+    # choose T instead which is a different dimension
+    # (and so a more meaningful plot)
+    assert _possible_x_y_plot(xtds, "x", skip="X") == "T"
+    # now with hue="lon", skip "X"
+    assert _possible_x_y_plot(xtds, "x", skip="lon") == "T"
+
 
 def test_groupby_special_ops():
     cfgrouped = airds.cf.groupby_bins("latitude", np.arange(20, 50, 10))
@@ -1404,6 +1444,30 @@ def test_cf_standard_name_table_version():
     assert expected_info == actual_info
 
 
+def test_add_canonical_attributes_0_dim():
+    """test if works for variables with 0 dimension"""
+    xr.DataArray(
+        0, attrs={"standard_name": "sea_water_potential_temperature"}
+    ).cf.add_canonical_attributes()
+
+
+@requires_cftime
+@pytest.mark.parametrize("reshape", [False, True])
+def test_datetime_like(reshape):
+    """test for 0 or >= 2 time dimensions"""
+    import cftime
+
+    data = cftime.datetime(2022, 1, 12)
+    if reshape:
+        data = [[data]]
+    da = xr.DataArray(
+        data,
+        attrs={"standard_name": "sea_water_age_since_surface_contact"},
+    )
+    new_attrs = da.cf.add_canonical_attributes().attrs
+    assert "units" not in new_attrs and "description" in new_attrs
+
+
 @pytest.mark.parametrize("override", [True, False])
 @pytest.mark.parametrize("skip", ["units", None])
 @pytest.mark.parametrize("verbose", [True, False])
@@ -1493,7 +1557,7 @@ def test_missing_variables():
 
     # Bounds
     ds = mollwds.copy(deep=True)
-    ds = ds.drop("lon_bounds")
+    ds = ds.drop_vars("lon_bounds")
     assert ds.cf.bounds == {"lat": ["lat_bounds"], "latitude": ["lat_bounds"]}
 
     with pytest.raises(KeyError, match=r"No results found for 'longitude'."):
@@ -1501,10 +1565,17 @@ def test_missing_variables():
 
     # Cell measures
     ds = airds.copy(deep=True)
-    ds = ds.drop("cell_area")
+    ds = ds.drop_vars("cell_area")
     assert ds.cf.cell_measures == {}
 
     # Formula terms
     ds = vert.copy(deep=True)
-    ds = ds.drop("ap")
+    ds = ds.drop_vars("ap")
     assert ds.cf.formula_terms == {"lev": {"b": "b", "ps": "ps"}}
+
+
+def test_pickle():
+    da = xr.DataArray([1.0], name="a")
+    ds = da.to_dataset()
+    pickle.loads(pickle.dumps(da.cf))
+    pickle.loads(pickle.dumps(ds.cf))
